@@ -1,7 +1,7 @@
 wdStyleSetup <-
     function (style="Normal",fontsize=11,align=3,wdapp = .R2wd)
 {
-    handle<-.R2wd[["ActiveDocument"]][["Styles"]]$Item("Normal")
+    handle<-.R2wd[["ActiveDocument"]][["Styles"]]$Item(style)
     handle[["Font"]][["Size"]]<-fontsize
     handle[["ParagraphFormat"]][["Alignment"]]<-align
     return()
